# **GRG**

## Computer Algebra System for Differential Geometry, Gravitation and Field Theory

----

## Introduction

The computer algebra system **GRG** is designed to make calculation in differential geometry and field theory as simple and natural as possible. **GRG** is based on the computer algebra system **REDUCE** but **GRG** has its own simple input language whose commands resemble short English phrases.

**GRG** understands tensors, spinors, vectors, differential forms and knows all standard operations with these quantities. Input form for mathematical expressions is very close to traditional mathematical notation including Einstein summation rule. **GRG** knows covariant properties of the objects: one can easily raise and lower indices, compute covariant and Lie derivatives, perform coordinate and frame transformations etc. **GRG** works in any dimension and allows one to represent tensor quantities with respect to holonomic, orthogonal and even any other arbitrary frame.

One of the key features of **GRG** is that it knows a large number of built-in usual field-theoretical and geometrical quantities and formulas for their computation providing ready solutions to many standard problems.

Another unique feature of **GRG** is that it can export results of calculations into other computer algebra system such as *Maple*, *Mathematica*, *Macsyma*, or ***REDUCE*** in order to use these systems to proceed with analysis of the data. The *LaTeX* output format is supported as well. **GRG** is compatible with the **REDUCE** graphical shells, providing book-quality output with Greek letters, integral signs, etc.

----

## Features

The main built-in **GRG** capabilities are:

- Connection, torsion and nonmetricity.
- Curvature.
- Spinorial formalism.
- Irreducible decomposition of the curvature, torsion, and nonmetricity in any dimension.
- Einstein equations.
- Scalar field with minimal and non-minimal interaction.
- Electromagnetic field.
- Yang-Mills field.
- Dirac spinor field.
- Geodesic equation.
- Null congruences and optical scalars.
- Kinematics for time-like congruences.
- Ideal and spin fluid.
- Newman-Penrose formalism.
- Gravitational equations for the theory with arbitrary gravitational Lagrangian in Riemann and Riemann-Cartan spaces.

----

## Availability

- [**GRG Homepage**](https://reduce-algebra.sourceforge.io/grg32/grg32.php)
- [GitHub Mirror](https://github.com/reduce-algebra/grg/)
- [SourceHut Mirror](https://git.sr.ht/~trn/grg/)
- [NotABug Mirror](https://notabug.org/reduce-algebra/grg)
- [Chisel Mirrpr](https://chiselapp.com/user/reduce-algebra/repository/grg)

----

## Documentation

- [User Manual and Reference Guide](https://github.com/reduce-algebra/grg/tree/master/doc)

----

## Author

```text
Vadim V. Zhytnikov
Physics Department, Faculty of Mathematics,
Moscow State Pedagogical University,
Davydovskii per. 4, Moscow 107140, Russia

Telephone (Home): (095) 188-16-11

E-mail: vvzhy@td.lpi.ac.ru

E-mail: grg@curie.phy.ncu.edu.tw
        Subject: for Zhytnikov
```

----

## License

- **GRG** is free of charge. See [LICENSE](https://github.com/reduce-algebra/grg/blob/master/LICENSE) for full details.

----

## Homepage

- [GRG Homepage](https://reduce-algebra.sourceforge.io/grg32/grg32.php)

----
